@@ -7,7 +7,6 @@ import (
 	"os"
 	"os/exec"
 	"path/filepath"
-	"regexp"
 	"strings"
 	"sync"
 
@@ -24,10 +23,8 @@ import (
 // Platform stores the os state
 type Platform struct {
 	OS              string
-	CatCmd          []string
 	Shell           string
 	ShellArg        string
-	EscapedQuote    string
 	OpenCommand     string
 	OpenLinkCommand string
 }
@@ -203,7 +200,14 @@ func (c *OSCommand) ShellCommandFromString(commandStr string) *exec.Cmd {
 	quotedCommand := ""
 	// Windows does not seem to like quotes around the command
 	if c.Platform.OS == "windows" {
-		quotedCommand = commandStr
+		quotedCommand = strings.NewReplacer(
+			"^", "^^",
+			"&", "^&",
+			"|", "^|",
+			"<", "^<",
+			">", "^>",
+			"%", "^%",
+		).Replace(commandStr)
 	} else {
 		quotedCommand = c.Quote(commandStr)
 	}
@@ -212,50 +216,6 @@ func (c *OSCommand) ShellCommandFromString(commandStr string) *exec.Cmd {
 	return c.ExecutableFromString(shellCommand)
 }
 
-// RunCommandWithOutputLive runs RunCommandWithOutputLiveWrapper
-func (c *OSCommand) RunCommandWithOutputLive(command string, output func(string) string) error {
-	return RunCommandWithOutputLiveWrapper(c, command, output)
-}
-
-func (c *OSCommand) CatFile(filename string) (string, error) {
-	arr := append(c.Platform.CatCmd, filename)
-	cmdStr := strings.Join(arr, " ")
-	c.Log.WithField("command", cmdStr).Info("Cat")
-	cmd := c.Command(arr[0], arr[1:]...)
-	output, err := sanitisedCommandOutput(cmd.CombinedOutput())
-	if err != nil {
-		c.Log.WithField("command", cmdStr).Error(output)
-	}
-	return output, err
-}
-
-// DetectUnamePass detect a username / password / passphrase question in a command
-// promptUserForCredential is a function that gets executed when this function detect you need to fillin a password or passphrase
-// The promptUserForCredential argument will be "username", "password" or "passphrase" and expects the user's password/passphrase or username back
-func (c *OSCommand) DetectUnamePass(command string, promptUserForCredential func(string) string) error {
-	ttyText := ""
-	errMessage := c.RunCommandWithOutputLive(command, func(word string) string {
-		ttyText = ttyText + " " + word
-
-		prompts := map[string]string{
-			`.+'s password:`:                         "password",
-			`Password\s*for\s*'.+':`:                 "password",
-			`Username\s*for\s*'.+':`:                 "username",
-			`Enter\s*passphrase\s*for\s*key\s*'.+':`: "passphrase",
-		}
-
-		for pattern, askFor := range prompts {
-			if match, _ := regexp.MatchString(pattern, ttyText); match {
-				ttyText = ""
-				return promptUserForCredential(askFor)
-			}
-		}
-
-		return ""
-	})
-	return errMessage
-}
-
 // RunCommand runs a command and just returns the error
 func (c *OSCommand) RunCommand(formatString string, formatArgs ...interface{}) error {
 	_, err := c.RunCommandWithOutput(formatString, formatArgs...)
@@ -265,7 +225,7 @@ func (c *OSCommand) RunCommand(formatString string, formatArgs ...interface{}) e
 // RunShellCommand runs shell commands i.e. 'sh -c <command>'. Good for when you
 // need access to the shell
 func (c *OSCommand) RunShellCommand(command string) error {
-	cmd := c.Command(c.Platform.Shell, c.Platform.ShellArg, command)
+	cmd := c.ShellCommandFromString(command)
 	c.LogExecCmd(cmd)
 
 	_, err := sanitisedCommandOutput(cmd.CombinedOutput())
@@ -301,17 +261,11 @@ func sanitisedCommandOutput(output []byte, err error) (string, error) {
 // OpenFile opens a file with the given
 func (c *OSCommand) OpenFile(filename string) error {
 	commandTemplate := c.Config.GetUserConfig().OS.OpenCommand
-	quoted := c.Quote(filename)
-	if c.Platform.OS == "linux" {
-		// Add extra quoting to avoid issues with shell command string
-		quoted = c.Quote(quoted)
-		quoted = quoted[1 : len(quoted)-1]
-	}
 	templateValues := map[string]string{
-		"filename": quoted,
+		"filename": c.Quote(filename),
 	}
 	command := utils.ResolvePlaceholderString(commandTemplate, templateValues)
-	err := c.RunCommand(command)
+	err := c.RunShellCommand(command)
 	return err
 }
 
@@ -324,7 +278,7 @@ func (c *OSCommand) OpenLink(link string) error {
 	}
 
 	command := utils.ResolvePlaceholderString(commandTemplate, templateValues)
-	err := c.RunCommand(command)
+	err := c.RunShellCommand(command)
 	return err
 }
 
@@ -346,17 +300,23 @@ func (c *OSCommand) PrepareShellSubProcess(command string) *exec.Cmd {
 
 // Quote wraps a message in platform-specific quotation marks
 func (c *OSCommand) Quote(message string) string {
+	var quote string
 	if c.Platform.OS == "windows" {
-		message = strings.Replace(message, `"`, `"'"'"`, -1)
-		message = strings.Replace(message, `\"`, `\\"`, -1)
+		quote = `\"`
+		message = strings.NewReplacer(
+			`"`, `"'"'"`,
+			`\"`, `\\"`,
+		).Replace(message)
 	} else {
-		message = strings.Replace(message, `\`, `\\`, -1)
-		message = strings.Replace(message, `"`, `\"`, -1)
-		message = strings.Replace(message, "`", "\\`", -1)
-		message = strings.Replace(message, "$", "\\$", -1)
+		quote = `"`
+		message = strings.NewReplacer(
+			`\`, `\\`,
+			`"`, `\"`,
+			`$`, `\$`,
+			"`", "\\`",
+		).Replace(message)
 	}
-	escapedQuote := c.Platform.EscapedQuote
-	return escapedQuote + message + escapedQuote
+	return quote + message + quote
 }
 
 // AppendLineToFile adds a new line in file
@@ -559,7 +519,9 @@ func RunLineOutputCmd(cmd *exec.Cmd, onLine func(line string) (bool, error)) err
 }
 
 func (c *OSCommand) CopyToClipboard(str string) error {
-	c.LogCommand(fmt.Sprintf("Copying '%s' to clipboard", utils.TruncateWithEllipsis(str, 40)), false)
+	escaped := strings.Replace(str, "\n", "\\n", -1)
+	truncated := utils.TruncateWithEllipsis(escaped, 40)
+	c.LogCommand(fmt.Sprintf("Copying '%s' to clipboard", truncated), false)
 	return clipboard.WriteAll(str)
 }
 
@@ -568,3 +530,30 @@ func (c *OSCommand) RemoveFile(path string) error {
 
 	return c.removeFile(path)
 }
+
+func (c *OSCommand) NewCmdObjFromStr(cmdStr string) ICmdObj {
+	args := str.ToArgv(cmdStr)
+	cmd := c.Command(args[0], args[1:]...)
+	cmd.Env = os.Environ()
+
+	return &CmdObj{
+		cmdStr: cmdStr,
+		cmd:    cmd,
+	}
+}
+
+func (c *OSCommand) NewCmdObjFromArgs(args []string) ICmdObj {
+	cmd := c.Command(args[0], args[1:]...)
+
+	return &CmdObj{
+		cmdStr: strings.Join(args, " "),
+		cmd:    cmd,
+	}
+}
+
+func (c *OSCommand) NewCmdObj(cmd *exec.Cmd) ICmdObj {
+	return &CmdObj{
+		cmdStr: strings.Join(cmd.Args, " "),
+		cmd:    cmd,
+	}
+}
