@@ -24,6 +24,7 @@ type RefresherConfig struct {
 }
 
 type GuiConfig struct {
+	AuthorColors             map[string]string  `yaml:"authorColors"`
 	ScrollHeight             int                `yaml:"scrollHeight"`
 	ScrollPastBottom         bool               `yaml:"scrollPastBottom"`
 	MouseEvents              bool               `yaml:"mouseEvents"`
@@ -68,7 +69,9 @@ type GitConfig struct {
 	OverrideGpg         bool                          `yaml:"overrideGpg"`
 	DisableForcePushing bool                          `yaml:"disableForcePushing"`
 	CommitPrefixes      map[string]CommitPrefixConfig `yaml:"commitPrefixes"`
-	ParseEmoji          bool                          `yaml:"parseEmoji"`
+	// this shoudl really be under 'gui', not 'git'
+	ParseEmoji bool      `yaml:"parseEmoji"`
+	Log        LogConfig `yaml:"log"`
 }
 
 type PagingConfig struct {
@@ -82,6 +85,11 @@ type MergingConfig struct {
 	Args         string `yaml:"args"`
 }
 
+type LogConfig struct {
+	Order     string `yaml:"order"`     // one of date-order, author-date-order, topo-order
+	ShowGraph string `yaml:"showGraph"` // one of always, never, when-maximised
+}
+
 type CommitPrefixConfig struct {
 	Pattern string `yaml:"pattern"`
 	Replace string `yaml:"replace"`
@@ -117,6 +125,8 @@ type KeybindingUniversalConfig struct {
 	NextItemAlt                  string   `yaml:"nextItem-alt"`
 	PrevPage                     string   `yaml:"prevPage"`
 	NextPage                     string   `yaml:"nextPage"`
+	ScrollLeft                   string   `yaml:"scrollLeft"`
+	ScrollRight                  string   `yaml:"scrollRight"`
 	GotoTop                      string   `yaml:"gotoTop"`
 	GotoBottom                   string   `yaml:"gotoBottom"`
 	PrevBlock                    string   `yaml:"prevBlock"`
@@ -227,6 +237,7 @@ type KeybindingCommitsConfig struct {
 	CheckoutCommit               string `yaml:"checkoutCommit"`
 	ResetCherryPick              string `yaml:"resetCherryPick"`
 	CopyCommitMessageToClipboard string `yaml:"copyCommitMessageToClipboard"`
+	OpenLogMenu                  string `yaml:"openLogMenu"`
 }
 
 type KeybindingStashConfig struct {
@@ -337,6 +348,10 @@ func GetDefaultConfig() *UserConfig {
 				ManualCommit: false,
 				Args:         "",
 			},
+			Log: LogConfig{
+				Order:     "topo-order",
+				ShowGraph: "when-maximised",
+			},
 			SkipHookPrefix:      "WIP",
 			AutoFetch:           true,
 			BranchLogCmd:        "git log --graph --color=always --abbrev-commit --decorate --date=relative --pretty=medium {{branchName}} --",
@@ -370,6 +385,8 @@ func GetDefaultConfig() *UserConfig {
 				NextItemAlt:                  "j",
 				PrevPage:                     ",",
 				NextPage:                     ".",
+				ScrollLeft:                   "H",
+				ScrollRight:                  "L",
 				GotoTop:                      "<",
 				GotoBottom:                   ">",
 				PrevBlock:                    "<left>",
@@ -476,6 +493,7 @@ func GetDefaultConfig() *UserConfig {
 				CheckoutCommit:               "<space>",
 				ResetCherryPick:              "<c-R>",
 				CopyCommitMessageToClipboard: "<c-y>",
+				OpenLogMenu:                  "<c-l>",
 			},
 			Stash: KeybindingStashConfig{
 				PopStash: "g",
