@@ -4,15 +4,12 @@ func dutchTranslationSet() TranslationSet {
 	return TranslationSet{
 		NotEnoughSpace:                      "Niet genoeg ruimte om de panelen te renderen",
 		DiffTitle:                           "Diff",
-		LogTitle:                            "Log",
 		FilesTitle:                          "Bestanden",
 		BranchesTitle:                       "Branches",
 		CommitsTitle:                        "Commits",
 		StashTitle:                          "Stash",
 		UnstagedChanges:                     `Unstaged wijzigingen`,
 		StagedChanges:                       `Staged wijzigingen`,
-		PatchBuildingMainTitle:              `Voeg lijnen/hunks toe aan patch`,
-		MergingMainTitle:                    "Los merge conflicten op",
 		MainTitle:                           "Hoofd",
 		StagingTitle:                        "Staging",
 		NormalTitle:                         "Normaal",
@@ -30,22 +27,18 @@ func dutchTranslationSet() TranslationSet {
 		LcNavigate:                          "navigeer",
 		LcMenu:                              "menu",
 		LcExecute:                           "uitvoeren",
-		LcOpen:                              "open",
-		LcIgnore:                            "negeren",
-		LcDelete:                            "verwijderen",
 		LcToggleStaged:                      "toggle staged",
 		LcToggleStagedAll:                   "toggle staged alle",
 		LcRefresh:                           "verversen",
 		LcPush:                              "push",
 		LcPull:                              "pull",
-		LcEdit:                              "bewerken",
 		LcScroll:                            "scroll",
-		LcAbortMerge:                        "samenvoegen afbreken",
-		LcResolveMergeConflicts:             "los merge conflicten op",
+		LcCommitFileFilter:                  "Commit dossiers filteren",
+		FilterStagedFiles:                   "Show only staged files",
+		FilterUnstagedFiles:                 "Show only unstaged files",
+		ResetCommitFilterState:              "Reset commit file state filter",
 		MergeConflictsTitle:                 "Merge Conflicten",
 		LcCheckout:                          "uitchecken",
-		FileHasNoUnstagedChanges:            "Het bestand heeft geen unstaged veranderingen om toe te voegen",
-		CannotGitAdd:                        "Kan commando niet uitvoeren git add --path untracked files",
 		NoFilesDisplay:                      "Geen bestanden om te laten zien",
 		NotAFile:                            "Dit is geen bestand",
 		PullWait:                            "Pullen...",
@@ -53,7 +46,6 @@ func dutchTranslationSet() TranslationSet {
 		FetchWait:                           "Fetchen...",
 		FileNoMergeCons:                     "Dit bestand heeft geen merge conflicten",
 		LcSoftReset:                         "zacht reset",
-		SureTo:                              "Weet je het zeker dat je {{.fileName}} wilt {{.deleteVerb}} (je veranderingen zullen worden verwijderd)",
 		AlreadyCheckedOutBranch:             "Je hebt deze branch al uitgecheckt",
 		SureForceCheckout:                   "Weet je zeker dat je het uitchecken wil forceren? Al je lokale verandering zullen worden verwijdert",
 		ForceCheckoutBranch:                 "Forceer uitchecken op deze branch",
@@ -67,27 +59,20 @@ func dutchTranslationSet() TranslationSet {
 		CantRebaseOntoSelf:                  "Je kan niet een branch rebasen op zichzelf",
 		CantMergeBranchIntoItself:           "Je kan niet een branch in zichzelf mergen",
 		LcForceCheckout:                     "forceer checkout",
-		LcMerge:                             "samenvoegen",
 		LcCheckoutByName:                    "uitchecken bij naam",
 		LcNewBranch:                         "nieuwe branch",
 		LcDeleteBranch:                      "verwijder branch",
-		LcForceDeleteBranch:                 "verwijder branch (forceer)",
 		NoBranchesThisRepo:                  "Geen branches voor deze repo",
-		NoTrackingThisBranch:                "deze branch wordt niet gevolgd",
 		CommitMessageConfirm:                "{{.keyBindClose}}: Sluiten, {{.keyBindNewLine}}: Nieuwe lijn, {{.keyBindConfirm}}: Bevestig",
 		CommitWithoutMessageErr:             "Je kan geen commit maken zonder commit bericht",
 		CloseConfirm:                        "{{.keyBindClose}}: Sluiten, {{.keyBindConfirm}}: Bevestig",
 		LcClose:                             "sluiten",
 		LcQuit:                              "quit",
-		SureResetThisCommit:                 "Weet je het zeker dat je wil resetten naar deze commit?",
-		ResetToCommit:                       "Reset Naar Commit",
 		LcSquashDown:                        "squash beneden",
-		LcRename:                            "hernoemen",
 		LcResetToThisCommit:                 "reset naar deze commit",
 		LcFixupCommit:                       "Fixup commit",
 		OnlySquashTopmostCommit:             "Kan alleen bovenste commit squashen",
 		YouNoCommitsToSquash:                "Je hebt geen commits om mee te squashen",
-		CantFixupWhileUnstagedChanges:       "Kan geen Fixup uitvoeren op unstaged veranderingen",
 		Fixup:                               "Fixup",
 		SureFixupThisCommit:                 "Weet je zeker dat je fixup wil uitvoeren op deze commit? De commit hieronder zol worden squashed in deze",
 		SureSquashThisCommit:                "Weet je zeker dat je deze commit wil samenvoegen met de commit hieronder?",
@@ -102,14 +87,12 @@ func dutchTranslationSet() TranslationSet {
 		LcEditCommit:                        "wijzig commit",
 		LcAmendToCommit:                     "wijzig commit met staged veranderingen",
 		LcRenameCommitEditor:                "hernoem commit met editor",
-		PotentialErrInGetselectedCommit:     "Er is mogelijk een error in getSelected Commit (geen match tussen ui en state)",
 		NoCommitsThisBranch:                 "Geen commits in deze branch",
 		Error:                               "Foutmelding",
-		RunningSubprocess:                   "subprocess lopend",
 		LcSelectHunk:                        "selecteer stuk",
 		LcNavigateConflicts:                 "navigeer conflicts",
 		LcPickHunk:                          "kies stuk",
-		LcPickBothHunks:                     "kies beide stukken",
+		LcPickAllHunks:                      "kies beide stukken",
 		LcUndo:                              "ongedaan maken",
 		LcUndoReflog:                        "ongedaan maken (via reflog) (experimenteel)",
 		LcRedoReflog:                        "redo (via reflog) (experimenteel)",
@@ -126,8 +109,6 @@ func dutchTranslationSet() TranslationSet {
 		NoStashTo:                           "Geen stash voor {{.method}}",
 		NoTrackedStagedFilesStash:           "Je hebt geen tracked/staged bestanden om te laten stashen",
 		StashChanges:                        "Stash veranderingen",
-		IssntListOfViews:                    "{{.name}} is niet in de lijst van weergaves",
-		LcNewFocusedViewIs:                  "nieuw gefocussed weergave is {{.newFocusedView}}",
 		NoChangedFiles:                      "Geen veranderde bestanden",
 		MergeAborted:                        "Merge afgebroken",
 		OpenConfig:                          "open config bestand",
@@ -141,8 +122,6 @@ func dutchTranslationSet() TranslationSet {
 		OnLatestVersionErr:                  "Je hebt al de laatste versie",
 		MajorVersionErr:                     "Nieuwe versie ({{.newVersion}}) is niet backwards compatibele vergeleken met de huidige versie ({{.currentVersion}})",
 		CouldNotFindBinaryErr:               "Kon geen binary vinden op {{.url}}",
-		AnonymousReportingTitle:             "Help lazygit te verbeteren",
-		AnonymousReportingPrompt:            "Zou je anonieme data rapportage willen aanzetten om lazygit beter te kunnen maken? (enter/esc)",
 		IntroPopupMessage:                   "Bedankt voor het gebruik maken van lazygit! 2 dingen die je moet weten:\n\n1) Als je meer van lazygit zijn features wilt leren bekijk dan deze video:\n   https://youtu.be/CPLdltN7wgE\n\n2) Als je git gebruikt, ben je een programmeur! Met jouw hulp kunnen we lazygit verbeteren, dus overweeg om een ​​donateur te worden en mee te doen aan het plezier op\n   https://github.com/jesseduffield/lazygit",
 		GitconfigParseErr:                   `Gogit kon je gitconfig bestand niet goed parsen door de aanwezigheid van losstaande '\' tekens. Het weghalen van deze tekens zou het probleem moeten oplossen. `,
 		LcEditFile:                          `verander bestand`,
@@ -162,24 +141,19 @@ func dutchTranslationSet() TranslationSet {
 		NoAutomaticGitFetchBody:             `Lazygit kan niet "git fetch" uitvoeren in een privé repository, gebruik f in het branches paneel om "git fetch" manueel uit te voeren`,
 		FileEnter:                           `stage individuele hunks/lijnen`,
 		FileStagingRequirements:             `Kan alleen individuele lijnen stagen van getrackte bestanden met onstaged veranderingen`,
-		SelectHunk:                          `selecteer hunk`,
 		StageSelection:                      `toggle lijnen staged / unstaged`,
 		ResetSelection:                      `verwijdert change (git reset)`,
 		ToggleDragSelect:                    `toggle drag selecteer`,
 		ToggleSelectHunk:                    `toggle selecteer hunk`,
 		ToggleSelectionForPatch:             `voeg toe/verwijder lijn(en) in patch`,
 		TogglePanel:                         `ga naar een ander paneel`,
-		CantStageStaged:                     `Je kan niet al gestaged verandering stagen!`,
 		ReturnToFilesPanel:                  `ga terug naar het bestanden paneel`,
-		CantFindHunks:                       `Kan geen hunks vinden in deze patch`,
-		CantFindHunk:                        `Kan geen hunk vinden`,
 		FastForward:                         `fast-forward deze branch vanaf zijn upstream`,
 		Fetching:                            "fetching en fast-forwarding {{.from}} -> {{.to}} ...",
 		FoundConflicts:                      "Conflicten!, Om af te breken druk 'esc', anders druk op 'enter'",
 		FoundConflictsTitle:                 "Auto-merge mislukt",
-		Undo:                                "ongedaan maken",
 		PickHunk:                            "kies hunk",
-		PickBothHunks:                       "kies bijde hunks",
+		PickAllHunks:                        "kies bijde hunks",
 		ViewMergeRebaseOptions:              "bekijk merge/rebase opties",
 		NotMergingOrRebasing:                "Je bent momenteel niet aan het rebasen of mergen",
 		RecentRepos:                         "recente repositories",
@@ -189,7 +163,6 @@ func dutchTranslationSet() TranslationSet {
 		LocalBranchesTitle:                  "Branches Tabblad",
 		SearchTitle:                         "Zoek",
 		TagsTitle:                           "Tags Tabblad",
-		BranchCommitsTitle:                  "Commits Tabblad",
 		MenuTitle:                           "Menu",
 		RemotesTitle:                        "Remotes Tabblad",
 		CredentialsTitle:                    "Credentials",
@@ -198,7 +171,6 @@ func dutchTranslationSet() TranslationSet {
 		InformationTitle:                    "Informatie",
 		SecondaryTitle:                      "Secondary",
 		ReflogCommitsTitle:                  "Reflog Tabblad",
-		Title:                               "Title",
 		GlobalTitle:                         "Globale Sneltoetsen",
 		ConflictsResolved:                   "alle merge conflicten zijn opgelost. Wilt je verder gaan?",
 		RebasingTitle:                       "Rebasen",
@@ -225,8 +197,8 @@ func dutchTranslationSet() TranslationSet {
 		NextHunk:                            "selecteer de volgende hunk",
 		PrevConflict:                        "selecteer voorgaand conflict",
 		NextConflict:                        "selecteer volgende conflict",
-		SelectTop:                           "selecteer bovenste hunk",
-		SelectBottom:                        "selecteer onderste hunk",
+		SelectPrevHunk:                      "selecteer bovenste hunk",
+		SelectNextHunk:                      "selecteer onderste hunk",
 		ScrollDown:                          "scroll omlaag",
 		ScrollUp:                            "scroll omhoog",
 		LcScrollUpMainPanel:                 "scroll naar beneden vanaf hoofdpaneel",
@@ -248,8 +220,6 @@ func dutchTranslationSet() TranslationSet {
 		CommitFiles:                         "Commit bestanden",
 		LcViewCommitFiles:                   "bekijk gecommite bestanden",
 		CommitFilesTitle:                    "Commit bestanden",
-		LcGoBack:                            "ga terug",
-		NoCommiteFiles:                      "Geen bestanden voor deze commit",
 		LcCheckoutCommitFile:                "bestand uitchecken",
 		LcDiscardOldFileChange:              "uitsluit deze commit zijn veranderingen aan dit bestand",
 		DiscardFileChangesTitle:             "uitsluit bestand zijn veranderingen",
@@ -268,7 +238,6 @@ func dutchTranslationSet() TranslationSet {
 		LcDiscardUntrackedFiles:             "negeer niet-gevonden bestanden",
 		LcViewResetOptions:                  `bekijk reset opties`,
 		LcHardReset:                         "harde reset",
-		LcHardResetUpstream:                 "harde naar upstream branch",
 		LcCreateFixupCommit:                 `creëer fixup commit voor deze commit`,
 		LcSquashAboveCommits:                `squash bovenstaande commits`,
 		SquashAboveCommits:                  `Squash bovenstaande commits`,
@@ -297,8 +266,6 @@ func dutchTranslationSet() TranslationSet {
 		LcEnterFile:                         "enter bestand om geselecteerde regels toe te voegen aan de patch",
 		ExitLineByLineMode:                  `sluit lijn-bij-lijn modus`,
 		EnterUpstream:                       `Enter upstream als '<remote> <branchnaam>'`,
-		EnterUpstreamWithSlash:              `Enter upstream als '<remote>/<branchnaam>'`,
-		LcNotTrackingRemote:                 "(nog geen remote aan het volgen)",
 		ReturnToRemotesList:                 `Ga terug naar remotes lijst`,
 		LcAddNewRemote:                      `voeg een nieuwe remote toe`,
 		LcNewRemoteName:                     `Nieuwe remote name:`,
@@ -360,7 +327,7 @@ func dutchTranslationSet() TranslationSet {
 		LcFilterBy:                          "filter bij",
 		LcExitFilterMode:                    "stop met filteren bij pad",
 		LcFilterPathOption:                  "vulin pad om op te filteren",
-		LcEnterFileName:                     "vulin path:",
+		EnterFileName:                       "Vulin path:",
 		FilteringMenuTitle:                  "Filteren",
 		MustExitFilterModeTitle:             "Command niet beschikbaar",
 		MustExitFilterModePrompt:            "Command niet beschikbaar in filter modus. Sluit filter modus?",
